#define STATE_INIT 0
#define STATE_BOTTOM_FLOOR_DEMAND 1
#define STATE_TIMING_1 2
#define STATE_TIMING_2 3
#define STATE_TIMING_3 4
#define STATE_IDLE_1 5
#define STATE_IDLE_2 6
#define STATE_IDLE_3 7
#define STATE_MOVING_1 8
#define STATE_MOVING_2 9
#define STATE_MOVING_3 10

#define DIRECTION_UP 0
#define DIRECTION_DOWN 1
