/* Screen Clearing Tool for RVController
 * A product of Advanced Mesecons Devices, a Cheapie Systems company
 * This is free and unencumbered software released into the public domain.
 * See http://unlicense.org/ for more information */

#include "rvcontroller-ecalls.h"

char color[] = "000000";
char channel[] = "A1";

void main(void) {
	for (int y=0;y<=5;y++) {
		channel[1] = '1' + y;
		for (int x=0;x<=19;x++) {
			channel[0] = 'A' + x;
			digiline_send(channel,color);
		}
	}
}
