#!/bin/bash
export PREFIX="/home/cheapie/rvcontroller/cross-toolchain/install" # Edit this for your system!
export TARGET=riscv32be-none-elf
export PATH="$PREFIX/bin:$PATH"
export PS1="(cross-be) $PS1"
export CC=clang
